sqlobject.versioning.test.test_version module — SQLObject 3.9.1 documentation

# sqlobject.versioning.test.test_version module

class `sqlobject.versioning.test.test_version.` `Base`(**kw)

  Bases: `sqlobject.inheritance.InheritableSQLObject`

  property `childName`
  `j` = base
  property `name`
  `q` = base
  property `so_value`
  class `sqlmeta`(instance)

    Bases: `sqlobject.inheritance.InheritableSQLMeta`

    `childClasses` = {'Child': <class 'sqlobject.versioning.test.test_version.Child'>, 'VChild': <class 'sqlobject.versioning.test.test_version.VChild'>}
    `childName` = None
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass` = None
    `soClass`

      alias of `sqlobject.versioning.test.test_version.Base`

    `table` = 'base'
  `versions`

class `sqlobject.versioning.test.test_version.` `Child`(**kw)

  Bases: `sqlobject.versioning.test.test_version.Base`

  property `childName`
  `j` = child
  property `name`
  `q` = child
  property `so_value`
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'Child'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.versioning.test.test_version.Base`

    `soClass`

      alias of `sqlobject.versioning.test.test_version.Child`

    `table` = 'child'
  property `toy`

class `sqlobject.versioning.test.test_version.` `Extra`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = extra
  property `name`
  `q` = extra
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.versioning.test.test_version.Extra`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'extra'
  `versions`

class `sqlobject.versioning.test.test_version.` `Government`(**kw)

  Bases: `sqlobject.inheritance.InheritableSQLObject`

  property `childName`
  `j` = government
  property `name`
  `q` = government
  class `sqlmeta`(instance)

    Bases: `sqlobject.inheritance.InheritableSQLMeta`

    `childClasses` = {'Monarchy': <class 'sqlobject.versioning.test.test_version.Monarchy'>}
    `childName` = None
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass` = None
    `soClass`

      alias of `sqlobject.versioning.test.test_version.Government`

    `table` = 'government'

class `sqlobject.versioning.test.test_version.` `HasAltId`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `altid`
  classmethod `byAltid`(val, connection=None)
  `j` = has_alt_id
  property `name`
  `q` = has_alt_id
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.versioning.test.test_version.HasAltId`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'has_alt_id'
  `versions`

class `sqlobject.versioning.test.test_version.` `HasForeign`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `foreign`
  property `foreignID`
  `j` = has_foreign
  `q` = has_foreign
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.versioning.test.test_version.HasForeign`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'has_foreign'
  `versions`

class `sqlobject.versioning.test.test_version.` `Monarchy`(**kw)

  Bases: `sqlobject.versioning.test.test_version.Government`

  property `childName`
  `j` = monarchy
  property `monarch`
  property `name`
  `q` = monarchy
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'Monarchy'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.versioning.test.test_version.Government`

    `soClass`

      alias of `sqlobject.versioning.test.test_version.Monarchy`

    `table` = 'monarchy'
  `versions`

class `sqlobject.versioning.test.test_version.` `MyClass`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = my_class
  property `name`
  `q` = my_class
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.versioning.test.test_version.MyClass`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'my_class'
  `versions`

class `sqlobject.versioning.test.test_version.` `VChild`(**kw)

  Bases: `sqlobject.versioning.test.test_version.Base`

  property `childName`
  `j` = vchild
  property `name`
  `q` = vchild
  property `so_value`
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'VChild'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.versioning.test.test_version.Base`

    `soClass`

      alias of `sqlobject.versioning.test.test_version.VChild`

    `table` = 'vchild'
  `versions`
  property `weapon`

`sqlobject.versioning.test.test_version.` `setup`()

`sqlobject.versioning.test.test_version.` `test_altid`()

`sqlobject.versioning.test.test_version.` `test_extra`()

`sqlobject.versioning.test.test_version.` `test_foreign_keys`()

`sqlobject.versioning.test.test_version.` `test_get_changed`()

`sqlobject.versioning.test.test_version.` `test_inheritable_versioning`()

`sqlobject.versioning.test.test_version.` `test_next`()

`sqlobject.versioning.test.test_version.` `test_restore`()

`sqlobject.versioning.test.test_version.` `test_versioning`()